@@ -7,13 +7,16 @@ from sphinx.config import Config
 from sphinx.errors import SphinxError
 from sphinx.roles import XRefRole
 
+from sphinxcontrib.needs.api.configuration import add_extra_option
 from sphinxcontrib.needs.builder import NeedsBuilder
+from sphinxcontrib.needs.config import NEEDS_CONFIG
 from sphinxcontrib.needs.defaults import (
     DEFAULT_DIAGRAM_TEMPLATE,
     LAYOUTS,
     NEED_DEFAULT_OPTIONS,
     NEEDEXTEND_NOT_ALLOWED_OPTIONS,
     NEEDFLOW_CONFIG_DEFAULTS,
+    NEEDS_TABLES_CLASSES,
 )
 from sphinxcontrib.needs.directives.need import (
     Need,
@@ -92,7 +95,7 @@ from sphinxcontrib.needs.services.manager import ServiceManager
 from sphinxcontrib.needs.utils import INTERNALS, NEEDS_FUNCTIONS
 from sphinxcontrib.needs.warnings import process_warnings
 
-VERSION = "0.7.1"
+VERSION = "0.7.2"
 NEEDS_FUNCTIONS.clear()
 
 
@@ -144,7 +147,7 @@ def setup(app):
     app.add_config_value("needs_role_need_template", "{title} ({id})", "html")
     app.add_config_value("needs_role_need_max_title_length", 30, "html", types=[int])
 
-    app.add_config_value("needs_extra_options", {}, "html")
+    app.add_config_value("needs_extra_options", [], "html")
     app.add_config_value("needs_title_optional", False, "html", types=[bool])
     app.add_config_value("needs_max_title_length", -1, "html", types=[int])
     app.add_config_value("needs_title_from_content", False, "html", types=[bool])
@@ -186,10 +189,13 @@ def setup(app):
     # Example: [{"name": "blocks, "incoming": "is blocked by", "copy_link": True, "color": "#ffcc00"}]
     app.add_config_value("needs_extra_links", [], "html")
 
+    app.add_config_value("needs_filter_data", {}, "html")
+
     app.add_config_value("needs_flow_show_links", False, "html")
     app.add_config_value("needs_flow_link_types", ["links"], "html")
 
     app.add_config_value("needs_warnings", {}, "html")
+    app.add_config_value("needs_warnings_always_warn", False, "html", types=[bool])
     app.add_config_value("needs_layouts", {}, "html")
     app.add_config_value("needs_default_layout", "clean", "html")
     app.add_config_value("needs_default_style", None, "html")
@@ -205,6 +211,11 @@ def setup(app):
 
     app.add_config_value("needs_external_needs", [], "html")
 
+    app.add_config_value("needs_builder_filter", "is_external==False", "html", types=[str])
+
+    # Additional classes to set for needs and needtable.
+    app.add_config_value("needs_table_classes", NEEDS_TABLES_CLASSES, "html", types=[list])
+
     # Define nodes
     app.add_node(Need, html=(html_visit, html_depart), latex=(latex_visit, latex_depart))
     app.add_node(
@@ -302,6 +313,11 @@ def setup(app):
     # This should be called last, so that need-styles can override styles from used libraries
     app.connect("env-updated", install_styles_static_files)
 
+    # Be sure Sphinx-Needs config gets erased before any events or external API calls get executed.
+    # So never but this inside an event.
+    NEEDS_CONFIG.create("extra_options", dict, overwrite=True)
+    NEEDS_CONFIG.create("warnings", dict, overwrite=True)
+
     return {
         "version": VERSION,
         "parallel_read_safe": True,
@@ -313,8 +329,21 @@ def load_config(app: Sphinx, *_args):
     """
     Register extra options and directive based on config from conf.py
     """
+    log = get_logger(__name__)
     types = app.config.needs_types
-    extra_options = app.config.needs_extra_options
+
+    if isinstance(app.config.needs_extra_options, dict):
+        log.info(
+            'Config option "needs_extra_options" supports list and dict. However new default type since '
+            "Sphinx-Needs 0.7.2 is list. Please see docs for details."
+        )
+
+    existing_extra_options = NEEDS_CONFIG.get("extra_options")
+    for option in app.config.needs_extra_options:
+        if option in existing_extra_options:
+            log.warning(f'extra_option "{option}" already registered.')
+        NEEDS_CONFIG.add("extra_options", {option: directives.unchanged}, dict, True)
+    extra_options = NEEDS_CONFIG.get("extra_options")
 
     # Get extra links and create a dictionary of needed options.
     extra_links_raw = app.config.needs_extra_links
@@ -386,6 +415,13 @@ def load_config(app: Sphinx, *_args):
         # Register requested types of needs
         app.add_directive(t["directive"], NeedDirective)
 
+    existing_warnings = NEEDS_CONFIG.get("warnings")
+    for name, check in app.config.needs_warnings.items():
+        if name not in existing_warnings:
+            NEEDS_CONFIG.add("warnings", {name: check}, dict, append=True)
+        else:
+            log.warning(f'{name} for "warnings" is already registered.')
+
 
 def visitor_dummy(*_args, **_kwargs):
     """
@@ -398,7 +434,6 @@ def prepare_env(app, env, _docname):
     """
     Prepares the sphinx environment to store sphinx-needs internal data.
     """
-
     if not hasattr(env, "needs_all_needs"):
         # Used to store all needed information about all needs in document
         env.needs_all_needs = {}
@@ -420,7 +455,10 @@ def prepare_env(app, env, _docname):
     for name, service in app.config.needs_services.items():
         if name not in app.needs_services.services.keys():
             # We found a not yet registered service
-            app.needs_services.register(name, service["class"], **service["class_init"])
+            # But only register, if service-config contains class and class_init.
+            # Otherwise the service may get registered later by an external sphinx-needs extension
+            if "class" in service and "class_init" in service:
+                app.needs_services.register(name, service["class"], **service["class_init"])
 
     needs_functions = app.config.needs_functions
 
@@ -435,8 +473,10 @@ def prepare_env(app, env, _docname):
     # Own extra options
     for option in ["hidden", "duration", "completion", "has_dead_links", "has_forbidden_dead_links"]:
         # Check if not already set by user
-        if option not in app.config.needs_extra_options.keys():
-            app.config.needs_extra_options[option] = directives.unchanged
+        # if option not in app.config.needs_extra_options:
+        #     app.config.needs_extra_options[option] = directives.unchanged
+        if option not in NEEDS_CONFIG.get("extra_options"):
+            add_extra_option(app, option)
 
     # The default link name. Must exist in all configurations. Therefore we set it here
     # for the user.
@@ -505,9 +545,22 @@ def check_configuration(_app: Sphinx, config: Config):
     extra_options = config["needs_extra_options"]
     link_types = [x["option"] for x in config["needs_extra_links"]]
 
+    external_filter = getattr(config, "needs_filter_data", {})
+    for extern_filter, value in external_filter.items():
+        # Check if external filter values is really a string
+        if not isinstance(value, str):
+            raise NeedsConfigException(
+                "External filter value: {0} from needs_filter_data {1} is not a string.".format(value, external_filter)
+            )
+        # Check if needs external filter and extra option are using the same name
+        if extern_filter in extra_options:
+            raise NeedsConfigException(
+                "Same name for external filter and extra option: {}." " This is not allowed.".format(extern_filter)
+            )
+
     # Check for usage of internal names
     for internal in INTERNALS:
-        if internal in extra_options.keys():
+        if internal in extra_options:
             raise NeedsConfigException(
                 'Extra option "{}" already used internally. ' " Please use another name.".format(internal)
             )
@@ -518,11 +571,11 @@ def check_configuration(_app: Sphinx, config: Config):
 
     # Check if option and link are using the same name
     for link in link_types:
-        if link in extra_options.keys():
+        if link in extra_options:
             raise NeedsConfigException(
                 "Same name for link type and extra option: {}." " This is not allowed.".format(link)
             )
-        if link + "_back" in extra_options.keys():
+        if link + "_back" in extra_options:
             raise NeedsConfigException(
                 "Same name for automatically created link type and extra option: {}."
                 " This is not allowed.".format(link + "_back")
